<?php
/**
 * Theme Functions
 */

/* == SVG Icon functions == */
require get_parent_theme_file_path('/icons/icon-functions.php');

/* == Customizer == */
require get_parent_theme_file_path('/inc/customizer.php');

/* == Theme setup == */
function aflatoon_setup() {
    load_theme_textdomain('aflatoon');
    add_theme_support('automatic-feed-links');
    add_theme_support('title-tag');
    add_theme_support('post-thumbnails');
    add_theme_support('custom-background', array('default-color' => 'ffffff'));
    add_image_size('aflatoon-featured-image', 1200, 640, true);
	add_editor_style();
    $GLOBALS['content_width'] = 525;
    register_nav_menus(array(
		'top' => __('Top Menu', 'aflatoon'),
	));
    add_theme_support('html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	));
    add_theme_support('post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'audio',
	));
    add_theme_support('custom-logo', array(
		'width'       => 100,
		'height'      => 100,
		'flex-width'  => true,
	));
    add_theme_support('customize-selective-refresh-widgets');
}
add_action('after_setup_theme', 'aflatoon_setup');

/* == Set the content width in pixels, based on the theme's design and stylesheet == */
function aflatoon_content_width() {
	$content_width = $GLOBALS['content_width'];
	$GLOBALS['content_width'] = apply_filters('aflatoon_content_width', $content_width);
}
add_action('template_redirect', 'aflatoon_content_width', 0);

/* == Register widgets == */
function aflatoon_widgets_init() {
    register_sidebar(array(
		'name'          => __('Blog Sidebar', 'aflatoon'),
		'id'            => 'sidebar-1',
		'description'   => __('Add widgets here to appear in your sidebar on blog posts and archive pages.', 'aflatoon'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));
}
add_action('widgets_init', 'aflatoon_widgets_init');

function aflatoon_sidebar_class() {
	if(is_active_sidebar('sidebar-1')) echo ' class="with-sidebar"';
}

/* == More link label == */
function aflatoon_more_label() {
	$more_link_label = get_theme_mod('more_link_label');
    //$more_link_label = '';
	if(empty($more_link_label)) $more_link_label = __('Read more','aflatoon');
	return $more_link_label;
}

/* == more link == */
function aflatoon_excerpt_more($link) {
	$more_link_label = aflatoon_more_label();
	
	if (is_admin()) {
		return $link;
	}

	$link = sprintf('<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
		esc_url(get_permalink(get_the_ID())),
		/* translators: %s: Name of current post */
		$more_link_label
	);
	return ' &hellip; ' . $link;
}
add_filter('excerpt_more', 'aflatoon_excerpt_more');

/* == Javascript detection == */
function aflatoon_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action('wp_head', 'aflatoon_javascript_detection', 0);

/* == Pingback url auto-discovery header for singularly identifiable articles == */
function aflatoon_pingback_header() {
	if (is_singular() && pings_open()) {
		printf('<link rel="pingback" href="%s">' . "\n", get_bloginfo('pingback_url'));
	}
}
add_action('wp_head', 'aflatoon_pingback_header');

/* == Load css/js scripts == */
function aflatoon_scripts() {

	// Google font stylesheet
	wp_register_style('aflatoon-fonts', 'https://fonts.googleapis.com/css?family=Roboto:300,300i,400,400i,700,700i|Raleway:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i|Anton', array(), null);
	
	//Normalize stylesheet
	wp_register_style('aflatoon-custom-reset', get_theme_file_uri('/css/custom-reset.css'));

	// Theme stylesheet.
	wp_enqueue_style('aflatoon-style', get_stylesheet_uri(), array('aflatoon-custom-reset', 'aflatoon-fonts'));	

	// Load the html5 shiv.
	wp_enqueue_script('html5', get_theme_file_uri('/js/html5.js'), array(), '3.7.3');
	wp_script_add_data('html5', 'conditional', 'lt IE 9');

	wp_register_script('jquery-rotate', get_theme_file_uri('/js/jQueryRotate.js'), array(), '2.3');
	//wp_register_script('infinite-scroll', get_theme_file_uri('/js/infinite-scroll.pkgd.min.js'), array(), '3.0.5');	
	wp_enqueue_script('aflatoon-global', get_theme_file_uri('/js/global.js'), array('jquery', 'jquery-rotate'), '1.0', true);	

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'aflatoon_scripts');

/**
 * Customizer CSS
 */
function aflatoon_custom_css() {
    $color_scheme = get_theme_mod('color_scheme');
	$logo_border = get_theme_mod('logo_border');
    $site_layout = get_theme_mod('site_layout');
    ?>
    <style type="text/css">
    <?php if($color_scheme != "" && $color_scheme != "#"): ?>
    a, .top-menu li a:hover, .top-menu > li.current-menu-item > a, .responsive-menu li a:hover, .responsive-menu > li.current-menu-item > a { color: <?php echo $color_scheme; ?>; }
    <?php endif; ?>
    <?php if($logo_border == "curved"): ?>
    .site-logo img { border-radius: 10px; }
    <?php elseif($logo_border == "rounded"): ?>
    .site-logo img { border-radius: 50%; }
    <?php endif; ?>
    <?php if($site_layout == "boxed"): ?>
    body { padding: 40px; }
    #page-wrap { max-width: 1100px; margin: 0 auto; }
    <?php endif; ?>
    </style>
    <?php
}
add_action('wp_head', 'aflatoon_custom_css');

/* == Display custom logo == */
function aflatoon_logo() {
    if(has_custom_logo()):
    echo '<div class="site-logo">';
    the_custom_logo();
    echo '</div>';
    endif;
}

/* == Display Site title and description == */
function aflatoon_site_info() {
    echo '<div class="site-info">';
    echo '<h1 class="site-title"><a href="'.esc_url(home_url('/')).'">'.get_bloginfo('name').'</a></h1>';
    if(get_bloginfo('description') != "") echo '<p class="site-description">'.get_bloginfo('description').'</p>';
    echo '</div>';
}

/* == Display Site navigation == */
function aflatoon_navigation($menu_id, $menu_class, $container_class) {
	?>
	<div class="site-nav site-nav-<?php echo $menu_class; ?>">		
		<nav class="<?php echo $menu_class; ?>-navigation" role="navigation" aria-label="<?php esc_attr_e('Nav Menu', 'aflatoon'); ?>">        
			<?php wp_nav_menu(array(
			'theme_location' => 'top',
			'menu_id' => $menu_id,
			'menu_class' => $menu_class,
			'container_class' => $container_class,
			'depth' => 3
		 )); ?>
		</nav>
	</div>
	<?php
}

if (! function_exists('aflatoon_posted_on')) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function aflatoon_posted_on() {
	// Get the author name; wrap it in a link.
	$byline = sprintf(
		/* translators: %s: post author */
		'<span class="screen-reader-text">'.__('by','aflatoon').'</span> %s',
		'<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . get_the_author() . '</a></span>'
	);

	// Finally, let's write all of this to the page.
	echo '<span class="posted-on">' . aflatoon_time_link() . '</span><span class="byline"> ' . $byline . '</span>';
}
endif;


if (! function_exists('aflatoon_time_link')) :
/**
 * Gets a nicely formatted string for the published date.
 */
function aflatoon_time_link() {
	$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
	if (get_the_time('U') !== get_the_modified_time('U')) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="entry-date updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf($time_string,
		get_the_date(DATE_W3C),
		get_the_date(),
		get_the_modified_date(DATE_W3C),
		get_the_modified_date()
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	return sprintf(
		/* translators: %s: post date */
		__('<span class="screen-reader-text">Posted on</span> %s', 'aflatoon'),
		'<a href="' . esc_url(get_permalink()) . '" rel="bookmark">' . $time_string . '</a>'
	);
}
endif;

/* == Display Comment link == */
function aflatoon_comment_link() {
    if(comments_open() && post_type_supports(get_post_type(), 'comments')):
    echo '<span class="entry-comment-link">';
	comments_popup_link('<span class="sep"></sep>'.__('Leave a Comment','aflatoon'), '<span class="sep"></sep>'.'1'.' '.__('Comment','aflatoon'), '<span class="sep"></sep>'.'%'.' '.__('Comments','aflatoon'), 'comments-link', '');
    echo '</span>';
    endif;
}

/* == Page pagination == */
function aflatoon_post_pagination() {
	// Previous/next page navigation.
	the_posts_pagination(array(
		'prev_text'          => __('Previous page', 'aflatoon'),
		'next_text'          => __('Next page', 'aflatoon'),
		'before_page_number' => '<span class="meta-nav screen-reader-text">' . __('Page', 'aflatoon') . ' </span>',
	));
}

/* == Display next page link for infinite scrolling == */
function aflatoon_infinite_pagination() {
	if(get_next_posts_link()) {
		echo '<div class="load-more-container">';
		next_posts_link(__('Load more','aflatoon'));
		echo '</div>';
	}
}

/* == Single post navigation == */
function aflatoon_post_navigation() {
	// Previous/next post navigation.
	the_post_navigation(array(
		'next_text' => '<span class="meta-nav meta-nav-next" aria-hidden="true">'.
			'<span class="screen-reader-text">' . __('Next Post', 'aflatoon') . '</span> ' .
			'<span class="post-title">%title</span>',
		'prev_text' => '<span class="meta-nav meta-nav-prev" aria-hidden="true">'.
			'<span class="screen-reader-text">' . __('Previous Post', 'aflatoon') . '</span> ' .
			'<span class="post-title">%title</span>',
	));
}

/* == Comment navigation == */
function aflatoon_comment_navigation() {
	the_comments_pagination(array(
		'prev_text' => '<span class="screen-reader-text">' . __('Previous', 'aflatoon') . '</span>',
		'next_text' => '<span class="screen-reader-text">' . __('Next', 'aflatoon') . '</span>',
	));
}

/* == Display post categories == */
function aflatoon_post_categories($before = '', $after = '') {
	$categories_list = get_the_category_list(_x(', ', 'Used between list items, there is a space after the comma.', 'aflatoon'));
	if ($categories_list) {
		echo $before;
		printf('<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
			_x('Categories', 'Used before category names.', 'aflatoon'),
			$categories_list
		);
		echo $after;
	}
}

/* == Display post tags == */
function aflatoon_post_tags($before = '', $after = '') {
	$tags_list = get_the_tag_list('', _x(', ', 'Used between list items, there is a space after the comma.', 'aflatoon'));
	if ($tags_list && ! is_wp_error($tags_list)) {
		echo $before;
		printf('<span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
			_x('Tags:', 'Used before tag names.', 'aflatoon'),
			$tags_list
		);
		echo $after;
	}
}

/* == Display copyright credit in footer == */
function aflatoon_footer_credit() {
	?>
	<div class="footer-credit">
		<p><?php _e('Copyright','aflatoon'); ?> &copy; <?php echo date('Y'); ?>. <?php bloginfo('name'); ?></p>
	</div>
	<?php
}
?>